import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Creates a new role for your AWS-account.
 *   For more information about roles, see [IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html) in the *IAM User Guide*. For information about quotas for role names and the number of roles you can create, see [IAM and quotas](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html) in the *IAM User Guide*.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const iamRole = new aws_native.iam.Role("iamRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: [
 *                     "cloudformation.amazonaws.com",
 *                     "gamelift.amazonaws.com",
 *                 ],
 *             },
 *             action: "sts:AssumeRole",
 *         }],
 *     },
 *     roleName: "ScriptIAMRole",
 *     policies: [{
 *         policyName: "ScriptResourceIAMPolicy",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: [
 *                     "s3:GetObject",
 *                     "s3:GetObjectVersion",
 *                     "s3:GetObjectMetadata",
 *                     "s3:*Object*",
 *                 ],
 *                 resource: ["*"],
 *             }],
 *         },
 *     }],
 * });
 * const scriptResource = new aws_native.gamelift.Script("scriptResource", {
 *     name: "MyRealtimeScript",
 *     version: "v1.0",
 *     storageLocation: {
 *         bucket: "MyBucketName",
 *         key: "MyScriptFiles.zip",
 *         roleArn: iamRole.arn,
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const iamRole = new aws_native.iam.Role("iamRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: [
 *                     "cloudformation.amazonaws.com",
 *                     "gamelift.amazonaws.com",
 *                 ],
 *             },
 *             action: "sts:AssumeRole",
 *         }],
 *     },
 *     roleName: "ScriptIAMRole",
 *     policies: [{
 *         policyName: "ScriptResourceIAMPolicy",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: [
 *                     "s3:GetObject",
 *                     "s3:GetObjectVersion",
 *                     "s3:GetObjectMetadata",
 *                     "s3:*Object*",
 *                 ],
 *                 resource: ["*"],
 *             }],
 *         },
 *     }],
 * });
 * const scriptResource = new aws_native.gamelift.Script("scriptResource", {
 *     name: "MyRealtimeScript",
 *     version: "v1.0",
 *     storageLocation: {
 *         bucket: "MyBucketName",
 *         key: "MyScriptFiles.zip",
 *         roleArn: iamRole.arn,
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myJobRole = new aws_native.iam.Role("myJobRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["glue.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 *     path: "/",
 *     policies: [{
 *         policyName: "root",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: "*",
 *                 resource: "*",
 *             }],
 *         },
 *     }],
 * });
 * const myJob = new aws_native.glue.Job("myJob", {
 *     command: {
 *         name: "glueetl",
 *         scriptLocation: "s3://<your-S3-script-uri>",
 *     },
 *     defaultArguments: {
 *         "--job-bookmark-option": "job-bookmark-enable",
 *     },
 *     executionProperty: {
 *         maxConcurrentRuns: 2,
 *     },
 *     maxRetries: 0,
 *     name: "cf-job1",
 *     role: myJobRole.id,
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myJobRole = new aws_native.iam.Role("myJobRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["glue.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 *     path: "/",
 *     policies: [{
 *         policyName: "root",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: "*",
 *                 resource: "*",
 *             }],
 *         },
 *     }],
 * });
 * const myJob = new aws_native.glue.Job("myJob", {
 *     command: {
 *         name: "glueetl",
 *         scriptLocation: "s3://<your-S3-script-uri>",
 *     },
 *     defaultArguments: {
 *         "--job-bookmark-option": "job-bookmark-enable",
 *     },
 *     executionProperty: {
 *         maxConcurrentRuns: 2,
 *     },
 *     maxRetries: 0,
 *     name: "cf-job1",
 *     role: myJobRole.id,
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myJobTriggerRole = new aws_native.iam.Role("myJobTriggerRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["glue.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 *     path: "/",
 *     policies: [{
 *         policyName: "root",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: "*",
 *                 resource: "*",
 *             }],
 *         },
 *     }],
 * });
 * const myJob = new aws_native.glue.Job("myJob", {
 *     name: "MyJobTriggerJob",
 *     logUri: "wikiData",
 *     role: myJobTriggerRole.id,
 *     command: {
 *         name: "glueetl",
 *         scriptLocation: "s3://testdata-bucket/s3-target/create-delete-job-xtf-ETL-s3-json-to-csv.py",
 *     },
 *     defaultArguments: {
 *         "--job-bookmark-option": "job-bookmark-enable",
 *     },
 *     maxRetries: 0,
 * });
 * const myJobTrigger = new aws_native.glue.Trigger("myJobTrigger", {
 *     name: "MyJobTrigger",
 *     type: "CONDITIONAL",
 *     description: "Description for a conditional job trigger",
 *     actions: [{
 *         jobName: myJob.id,
 *         arguments: {
 *             "--job-bookmark-option": "job-bookmark-enable",
 *         },
 *     }],
 *     predicate: {
 *         conditions: [{
 *             logicalOperator: "EQUALS",
 *             jobName: myJob.id,
 *             state: "SUCCEEDED",
 *         }],
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myJobTriggerRole = new aws_native.iam.Role("myJobTriggerRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["glue.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 *     path: "/",
 *     policies: [{
 *         policyName: "root",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: "*",
 *                 resource: "*",
 *             }],
 *         },
 *     }],
 * });
 * const myJob = new aws_native.glue.Job("myJob", {
 *     name: "MyJobTriggerJob",
 *     logUri: "wikiData",
 *     role: myJobTriggerRole.id,
 *     command: {
 *         name: "glueetl",
 *         scriptLocation: "s3://testdata-bucket/s3-target/create-delete-job-xtf-ETL-s3-json-to-csv.py",
 *     },
 *     defaultArguments: {
 *         "--job-bookmark-option": "job-bookmark-enable",
 *     },
 *     maxRetries: 0,
 * });
 * const myJobTrigger = new aws_native.glue.Trigger("myJobTrigger", {
 *     name: "MyJobTrigger",
 *     type: "CONDITIONAL",
 *     description: "Description for a conditional job trigger",
 *     actions: [{
 *         jobName: myJob.id,
 *         arguments: {
 *             "--job-bookmark-option": "job-bookmark-enable",
 *         },
 *     }],
 *     predicate: {
 *         conditions: [{
 *             logicalOperator: "EQUALS",
 *             jobName: myJob.id,
 *             state: "SUCCEEDED",
 *         }],
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const amazonGrafanaWorkspaceIAMRole = new aws_native.iam.Role("amazonGrafanaWorkspaceIAMRole", {
 *     managedPolicyArns: ["arn:aws:iam::aws:policy/service-role/AmazonGrafanaAthenaAccess"],
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["grafana.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 * });
 * const amazonGrafanaWorkspace = new aws_native.grafana.Workspace("amazonGrafanaWorkspace", {
 *     accountAccessType: aws_native.grafana.WorkspaceAccountAccessType.CurrentAccount,
 *     name: "AmazonGrafanaWorkspace",
 *     description: "Amazon Grafana Workspace",
 *     authenticationProviders: [aws_native.grafana.WorkspaceAuthenticationProviderTypes.Saml],
 *     permissionType: aws_native.grafana.WorkspacePermissionType.CustomerManaged,
 *     grafanaVersion: "9.4",
 *     roleArn: amazonGrafanaWorkspaceIAMRole.arn,
 *     samlConfiguration: {
 *         idpMetadata: {
 *             xml: "<md:EntityDescriptor xmlns:md='urn:oasis:names:tc:SAML:2.0:metadata' entityID='entityId'>DATA</md:EntityDescriptor>",
 *         },
 *         assertionAttributes: {
 *             name: "displayName",
 *             login: "login",
 *             email: "email",
 *             groups: "group",
 *             role: "role",
 *             org: "org",
 *         },
 *         roleValues: {
 *             editor: ["editor1"],
 *             admin: ["admin1"],
 *         },
 *         allowedOrganizations: ["org1"],
 *         loginValidityDuration: 60,
 *     },
 * });
 * export const workspaceEndpoint = amazonGrafanaWorkspace.endpoint;
 * export const workspaceStatus = amazonGrafanaWorkspace.status;
 * export const workspaceId = amazonGrafanaWorkspace.id;
 * export const grafanaVersion = amazonGrafanaWorkspace.grafanaVersion;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const amazonGrafanaWorkspaceIAMRole = new aws_native.iam.Role("amazonGrafanaWorkspaceIAMRole", {
 *     managedPolicyArns: ["arn:aws:iam::aws:policy/service-role/AmazonGrafanaAthenaAccess"],
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["grafana.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 * });
 * const amazonGrafanaWorkspace = new aws_native.grafana.Workspace("amazonGrafanaWorkspace", {
 *     accountAccessType: aws_native.grafana.WorkspaceAccountAccessType.CurrentAccount,
 *     name: "AmazonGrafanaWorkspace",
 *     description: "Amazon Grafana Workspace",
 *     authenticationProviders: [aws_native.grafana.WorkspaceAuthenticationProviderTypes.Saml],
 *     permissionType: aws_native.grafana.WorkspacePermissionType.CustomerManaged,
 *     grafanaVersion: "9.4",
 *     roleArn: amazonGrafanaWorkspaceIAMRole.arn,
 *     samlConfiguration: {
 *         idpMetadata: {
 *             xml: "<md:EntityDescriptor xmlns:md='urn:oasis:names:tc:SAML:2.0:metadata' entityID='entityId'>DATA</md:EntityDescriptor>",
 *         },
 *         assertionAttributes: {
 *             name: "displayName",
 *             login: "login",
 *             email: "email",
 *             groups: "group",
 *             role: "role",
 *             org: "org",
 *         },
 *         roleValues: {
 *             editor: ["editor1"],
 *             admin: ["admin1"],
 *         },
 *         allowedOrganizations: ["org1"],
 *         loginValidityDuration: 60,
 *     },
 * });
 * export const workspaceEndpoint = amazonGrafanaWorkspace.endpoint;
 * export const workspaceStatus = amazonGrafanaWorkspace.status;
 * export const workspaceId = amazonGrafanaWorkspace.id;
 * export const grafanaVersion = amazonGrafanaWorkspace.grafanaVersion;
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const rootRole = new aws_native.iam.Role("rootRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["ec2.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 *     path: "/",
 *     policies: [{
 *         policyName: "root",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: "*",
 *                 resource: "*",
 *             }],
 *         },
 *     }],
 * });
 * const rootInstanceProfile = new aws_native.iam.InstanceProfile("rootInstanceProfile", {
 *     path: "/",
 *     roles: [rootRole.id],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const rootRole = new aws_native.iam.Role("rootRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: ["ec2.amazonaws.com"],
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 *     path: "/",
 *     policies: [{
 *         policyName: "root",
 *         policyDocument: {
 *             version: "2012-10-17",
 *             statement: [{
 *                 effect: "Allow",
 *                 action: "*",
 *                 resource: "*",
 *             }],
 *         },
 *     }],
 * });
 * const rootInstanceProfile = new aws_native.iam.InstanceProfile("rootInstanceProfile", {
 *     path: "/",
 *     roles: [rootRole.id],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const automationExecutionRole = new aws_native.iam.Role("automationExecutionRole", {
 *     assumeRolePolicyDocument: {
 *         version: "2012-10-17",
 *         statement: [{
 *             effect: "Allow",
 *             principal: {
 *                 service: "ssm.amazonaws.com",
 *             },
 *             action: ["sts:AssumeRole"],
 *         }],
 *     },
 *     path: "/",
 *     managedPolicyArns: ["arn:${AWS::Partition}:iam::aws:policy/AmazonEC2FullAccess"],
 * });
 * const automationAssociation = new aws_native.ssm.Association("automationAssociation", {
 *     name: "AWS-StopEC2Instance",
 *     parameters: {
 *         automationAssumeRole: ["AutomationExecutionRole.Arn"],
 *     },
 *     targets: [{
 *         key: "ParameterValues",
 *         values: ["i-1234567890abcdef0"],
 *     }],
 *     automationTargetParameterName: "InstanceId",
 * });
 *
 * ```
 */
export declare class Role extends pulumi.CustomResource {
    /**
     * Get an existing Role resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Role;
    /**
     * Returns true if the given object is an instance of Role.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Role;
    /**
     * Returns the Amazon Resource Name (ARN) for the role. For example:
     *
     * `{"Fn::GetAtt" : ["MyRole", "Arn"] }`
     *
     * This will return a value such as `arn:aws:iam::1234567890:role/MyRole-AJJHDSKSDF` .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The trust policy that is associated with this role. Trust policies define which entities can assume the role. You can associate only one trust policy with a role. For an example of a policy that can be used to assume a role, see [Template Examples](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iam-role.html#aws-resource-iam-role--examples). For more information about the elements that you can use in an IAM policy, see [Policy Elements Reference](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements.html) in the *User Guide*.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::IAM::Role` for more information about the expected schema for this property.
     */
    readonly assumeRolePolicyDocument: pulumi.Output<any>;
    /**
     * A description of the role that you provide.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A list of Amazon Resource Names (ARNs) of the IAM managed policies that you want to attach to the role.
     *  For more information about ARNs, see [Amazon Resource Names (ARNs) and Service Namespaces](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference*.
     */
    readonly managedPolicyArns: pulumi.Output<string[] | undefined>;
    /**
     * The maximum session duration (in seconds) that you want to set for the specified role. If you do not specify a value for this setting, the default value of one hour is applied. This setting can have a value from 1 hour to 12 hours.
     *  Anyone who assumes the role from the CLI or API can use the ``DurationSeconds`` API parameter or the ``duration-seconds`` CLI parameter to request a longer session. The ``MaxSessionDuration`` setting determines the maximum duration that can be requested using the ``DurationSeconds`` parameter. If users don't specify a value for the ``DurationSeconds`` parameter, their security credentials are valid for one hour by default. This applies when you use the ``AssumeRole*`` API operations or the ``assume-role*`` CLI operations but does not apply when you use those operations to create a console URL. For more information, see [Using IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html) in the *IAM User Guide*.
     */
    readonly maxSessionDuration: pulumi.Output<number | undefined>;
    /**
     * The path to the role. For more information about paths, see [IAM Identifiers](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html) in the *IAM User Guide*.
     *  This parameter is optional. If it is not included, it defaults to a slash (/).
     *  This parameter allows (through its [regex pattern](https://docs.aws.amazon.com/http://wikipedia.org/wiki/regex)) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (``\u0021``) through the DEL character (``\u007F``), including most punctuation characters, digits, and upper and lowercased letters.
     */
    readonly path: pulumi.Output<string | undefined>;
    /**
     * The ARN of the policy used to set the permissions boundary for the role.
     *  For more information about permissions boundaries, see [Permissions boundaries for IAM identities](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html) in the *IAM User Guide*.
     */
    readonly permissionsBoundary: pulumi.Output<string | undefined>;
    /**
     * Adds or updates an inline policy document that is embedded in the specified IAM role.
     *
     * When you embed an inline policy in a role, the inline policy is used as part of the role's access (permissions) policy. The role's trust policy is created at the same time as the role. You can update a role's trust policy later. For more information about IAM roles, go to [Using Roles to Delegate Permissions and Federate Identities](https://docs.aws.amazon.com/IAM/latest/UserGuide/roles-toplevel.html) .
     *
     * A role can also have an attached managed policy. For information about policies, see [Managed Policies and Inline Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html) in the *IAM User Guide* .
     *
     * For information about limits on the number of inline policies that you can embed with a role, see [Limitations on IAM Entities](https://docs.aws.amazon.com/IAM/latest/UserGuide/LimitationsOnEntities.html) in the *IAM User Guide* .
     *
     * > If an external policy (such as `AWS::IAM::Policy` or `AWS::IAM::ManagedPolicy` ) has a `Ref` to a role and if a resource (such as `AWS::ECS::Service` ) also has a `Ref` to the same role, add a `DependsOn` attribute to the resource to make the resource depend on the external policy. This dependency ensures that the role's policy is available throughout the resource's lifecycle. For example, when you delete a stack with an `AWS::ECS::Service` resource, the `DependsOn` attribute ensures that AWS CloudFormation deletes the `AWS::ECS::Service` resource before deleting its role's policy.
     */
    readonly policies: pulumi.Output<outputs.iam.RolePolicy[] | undefined>;
    /**
     * Returns the stable and unique string identifying the role. For example, `AIDAJQABLZS4A3QDU576Q` .
     *
     * For more information about IDs, see [IAM Identifiers](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html) in the *IAM User Guide* .
     */
    readonly roleId: pulumi.Output<string>;
    /**
     * A name for the IAM role, up to 64 characters in length. For valid values, see the `RoleName` parameter for the [`CreateRole`](https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html) action in the *IAM User Guide* .
     *
     * This parameter allows (per its [regex pattern](https://docs.aws.amazon.com/http://wikipedia.org/wiki/regex) ) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. The role name must be unique within the account. Role names are not distinguished by case. For example, you cannot create roles named both "Role1" and "role1".
     *
     * If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the role name.
     *
     * If you specify a name, you must specify the `CAPABILITY_NAMED_IAM` value to acknowledge your template's capabilities. For more information, see [Acknowledging IAM Resources in AWS CloudFormation Templates](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-capabilities) .
     *
     * > Naming an IAM resource can cause an unrecoverable error if you reuse the same template in multiple Regions. To prevent this, we recommend using `Fn::Join` and `AWS::Region` to create a Region-specific name, as in the following example: `{"Fn::Join": ["", [{"Ref": "AWS::Region"}, {"Ref": "MyResourceName"}]]}` .
     */
    readonly roleName: pulumi.Output<string | undefined>;
    /**
     * A list of tags that are attached to the role. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the *IAM User Guide*.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Role resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RoleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Role resource.
 */
export interface RoleArgs {
    /**
     * The trust policy that is associated with this role. Trust policies define which entities can assume the role. You can associate only one trust policy with a role. For an example of a policy that can be used to assume a role, see [Template Examples](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-iam-role.html#aws-resource-iam-role--examples). For more information about the elements that you can use in an IAM policy, see [Policy Elements Reference](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements.html) in the *User Guide*.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::IAM::Role` for more information about the expected schema for this property.
     */
    assumeRolePolicyDocument: any;
    /**
     * A description of the role that you provide.
     */
    description?: pulumi.Input<string>;
    /**
     * A list of Amazon Resource Names (ARNs) of the IAM managed policies that you want to attach to the role.
     *  For more information about ARNs, see [Amazon Resource Names (ARNs) and Service Namespaces](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference*.
     */
    managedPolicyArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The maximum session duration (in seconds) that you want to set for the specified role. If you do not specify a value for this setting, the default value of one hour is applied. This setting can have a value from 1 hour to 12 hours.
     *  Anyone who assumes the role from the CLI or API can use the ``DurationSeconds`` API parameter or the ``duration-seconds`` CLI parameter to request a longer session. The ``MaxSessionDuration`` setting determines the maximum duration that can be requested using the ``DurationSeconds`` parameter. If users don't specify a value for the ``DurationSeconds`` parameter, their security credentials are valid for one hour by default. This applies when you use the ``AssumeRole*`` API operations or the ``assume-role*`` CLI operations but does not apply when you use those operations to create a console URL. For more information, see [Using IAM roles](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html) in the *IAM User Guide*.
     */
    maxSessionDuration?: pulumi.Input<number>;
    /**
     * The path to the role. For more information about paths, see [IAM Identifiers](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_Identifiers.html) in the *IAM User Guide*.
     *  This parameter is optional. If it is not included, it defaults to a slash (/).
     *  This parameter allows (through its [regex pattern](https://docs.aws.amazon.com/http://wikipedia.org/wiki/regex)) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (``\u0021``) through the DEL character (``\u007F``), including most punctuation characters, digits, and upper and lowercased letters.
     */
    path?: pulumi.Input<string>;
    /**
     * The ARN of the policy used to set the permissions boundary for the role.
     *  For more information about permissions boundaries, see [Permissions boundaries for IAM identities](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies_boundaries.html) in the *IAM User Guide*.
     */
    permissionsBoundary?: pulumi.Input<string>;
    /**
     * Adds or updates an inline policy document that is embedded in the specified IAM role.
     *
     * When you embed an inline policy in a role, the inline policy is used as part of the role's access (permissions) policy. The role's trust policy is created at the same time as the role. You can update a role's trust policy later. For more information about IAM roles, go to [Using Roles to Delegate Permissions and Federate Identities](https://docs.aws.amazon.com/IAM/latest/UserGuide/roles-toplevel.html) .
     *
     * A role can also have an attached managed policy. For information about policies, see [Managed Policies and Inline Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html) in the *IAM User Guide* .
     *
     * For information about limits on the number of inline policies that you can embed with a role, see [Limitations on IAM Entities](https://docs.aws.amazon.com/IAM/latest/UserGuide/LimitationsOnEntities.html) in the *IAM User Guide* .
     *
     * > If an external policy (such as `AWS::IAM::Policy` or `AWS::IAM::ManagedPolicy` ) has a `Ref` to a role and if a resource (such as `AWS::ECS::Service` ) also has a `Ref` to the same role, add a `DependsOn` attribute to the resource to make the resource depend on the external policy. This dependency ensures that the role's policy is available throughout the resource's lifecycle. For example, when you delete a stack with an `AWS::ECS::Service` resource, the `DependsOn` attribute ensures that AWS CloudFormation deletes the `AWS::ECS::Service` resource before deleting its role's policy.
     */
    policies?: pulumi.Input<pulumi.Input<inputs.iam.RolePolicyArgs>[]>;
    /**
     * A name for the IAM role, up to 64 characters in length. For valid values, see the `RoleName` parameter for the [`CreateRole`](https://docs.aws.amazon.com/IAM/latest/APIReference/API_CreateRole.html) action in the *IAM User Guide* .
     *
     * This parameter allows (per its [regex pattern](https://docs.aws.amazon.com/http://wikipedia.org/wiki/regex) ) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. The role name must be unique within the account. Role names are not distinguished by case. For example, you cannot create roles named both "Role1" and "role1".
     *
     * If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the role name.
     *
     * If you specify a name, you must specify the `CAPABILITY_NAMED_IAM` value to acknowledge your template's capabilities. For more information, see [Acknowledging IAM Resources in AWS CloudFormation Templates](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-iam-template.html#using-iam-capabilities) .
     *
     * > Naming an IAM resource can cause an unrecoverable error if you reuse the same template in multiple Regions. To prevent this, we recommend using `Fn::Join` and `AWS::Region` to create a Region-specific name, as in the following example: `{"Fn::Join": ["", [{"Ref": "AWS::Region"}, {"Ref": "MyResourceName"}]]}` .
     */
    roleName?: pulumi.Input<string>;
    /**
     * A list of tags that are attached to the role. For more information about tagging, see [Tagging IAM resources](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_tags.html) in the *IAM User Guide*.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
