import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The ``AWS::Lambda::Function`` resource creates a Lambda function. To create a function, you need a [deployment package](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html) and an [execution role](https://docs.aws.amazon.com/lambda/latest/dg/lambda-intro-execution-role.html). The deployment package is a .zip file archive or container image that contains your function code. The execution role grants the function permission to use AWS services, such as Amazon CloudWatch Logs for log streaming and AWS X-Ray for request tracing.
 *  You set the package type to ``Image`` if the deployment package is a [container image](https://docs.aws.amazon.com/lambda/latest/dg/lambda-images.html). For these functions, include the URI of the container image in the ECR registry in the [ImageUri property of the Code property](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lambda-function-code.html#cfn-lambda-function-code-imageuri). You do not need to specify the handler and runtime properties.
 *  You set the package type to ``Zip`` if the deployment package is a [.zip file archive](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html#gettingstarted-package-zip). For these functions, specify the S3 location of your .zip file in the ``Code`` property. Alternatively, for Node.js and Python functions, you can define your function inline in the [ZipFile property of the Code property](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-lambda-function-code.html#cfn-lambda-function-code-zipfile). In both cases, you must also specify the handler and runtime properties.
 *  You can use [code signing](https://docs.aws.amazon.com/lambda/latest/dg/configuration-codesigning.html) if your deployment package is a .zip file archive. To enable code signing for this function, specify the ARN of a code-signing configuration. When a user attempts to deploy a code package with ``UpdateFunctionCode``, Lambda checks that the code package has a valid signature from a trusted publisher. The code-signing configuration includes a set of signing profiles, which define the trusted publishers for this function.
 *  When you update a ``AWS::Lambda::Function`` resource, CFNshort calls the [UpdateFunctionConfiguration](https://docs.aws.amazon.com/lambda/latest/api/API_UpdateFunctionConfiguration.html) and [UpdateFunctionCode](https://docs.aws.amazon.com/lambda/latest/api/API_UpdateFunctionCode.html) LAM APIs under the hood. Because these calls happen sequentially, and invocations can happen between these calls, your function may encounter errors in the time between the calls. For example, if you remove an environment variable, and the code that references that environment variable in the same CFNshort update, you may see invocation errors related to a missing environment variable. To work around this, you can invoke your function against a version or alias by default, rather than the ``$LATEST`` version.
 *  Note that you configure [provisioned concurrency](https://docs.aws.amazon.com/lambda/latest/dg/provisioned-concurrency.html) on a ``AWS::Lambda::Version`` or a ``AWS::Lambda::Alias``.
 *  For a complete introduction to Lambda functions, see [What is Lambda?](https://docs.aws.amazon.com/lambda/latest/dg/lambda-welcome.html) in the *Lambda developer guide.*
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const _function = new aws_native.lambda.Function("function", {
 *     handler: "index.handler",
 *     role: "arn:aws:iam::123456789012:role/lambda-role",
 *     code: {
 *         zipFile: `exports.handler = function(event){
 *     console.log(JSON.stringify(event, null, 2))
 *     const response = {
 *         statusCode: 200,
 *         body: JSON.stringify('Hello from Lambda!')
 *     }
 *     return response
 * };
 * `,
 *     },
 *     runtime: "nodejs18.x",
 *     tracingConfig: {
 *         mode: aws_native.lambda.FunctionTracingConfigMode.Active,
 *     },
 * });
 * const version = new aws_native.lambda.Version("version", {
 *     functionName: _function.id,
 *     description: "v1",
 * });
 * const alias = new aws_native.lambda.Alias("alias", {
 *     functionName: _function.id,
 *     functionVersion: version.version,
 *     name: "BLUE",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const _function = new aws_native.lambda.Function("function", {
 *     handler: "index.handler",
 *     role: "arn:aws:iam::123456789012:role/lambda-role",
 *     code: {
 *         zipFile: `exports.handler = function(event){
 *     console.log(JSON.stringify(event, null, 2))
 *     const response = {
 *         statusCode: 200,
 *         body: JSON.stringify('Hello again from Lambda!')
 *     }
 *     return response
 * }
 * `,
 *     },
 *     runtime: "nodejs18.x",
 *     tracingConfig: {
 *         mode: aws_native.lambda.FunctionTracingConfigMode.Active,
 *     },
 * });
 * const version = new aws_native.lambda.Version("version", {
 *     functionName: _function.id,
 *     description: "v1",
 * });
 * const newVersion = new aws_native.lambda.Version("newVersion", {
 *     functionName: _function.id,
 *     description: "v2",
 * });
 * const alias = new aws_native.lambda.Alias("alias", {
 *     functionName: _function.id,
 *     functionVersion: newVersion.version,
 *     name: "BLUE",
 *     routingConfig: {
 *         additionalVersionWeights: [{
 *             functionVersion: version.version,
 *             functionWeight: 0.5,
 *         }],
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const _function = new aws_native.lambda.Function("function", {
 *     handler: "index.handler",
 *     role: "arn:aws:iam::123456789012:role/lambda-role",
 *     code: {
 *         zipFile: `exports.handler = async (event) => {
 *     console.log(JSON.stringify(event, null, 2));
 *     const response = {
 *         statusCode: 200,
 *         body: JSON.stringify('Hello from Lambda!'),
 *     };
 *     return response;
 * };
 * `,
 *     },
 *     runtime: "nodejs18.x",
 *     tracingConfig: {
 *         mode: aws_native.lambda.FunctionTracingConfigMode.Active,
 *     },
 * });
 * const version = new aws_native.lambda.Version("version", {functionName: _function.id});
 * const asyncconfig = new aws_native.lambda.EventInvokeConfig("asyncconfig", {
 *     destinationConfig: {
 *         onFailure: {
 *             destination: "arn:aws:sqs:us-east-2:123456789012:dlq",
 *         },
 *         onSuccess: {
 *             destination: "arn:aws:sqs:us-east-2:123456789012:dlq",
 *         },
 *     },
 *     functionName: _function.id,
 *     maximumEventAgeInSeconds: 300,
 *     maximumRetryAttempts: 1,
 *     qualifier: version.version,
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const primer = new aws_native.lambda.Function("primer", {
 *     runtime: "nodejs18.x",
 *     role: "arn:aws:iam::123456789012:role/lambda-role",
 *     handler: "index.handler",
 *     code: {
 *         zipFile: `const { S3Client, ListBucketsCommand } = require("@aws-sdk/client-s3");
 * const s3 = new S3Client({ region: "us-east-1" }); // replace "us-east-1" with your AWS region
 *
 * exports.handler = async function(event) {
 *   const command = new ListBucketsCommand({});
 *   const response = await s3.send(command);
 *   return response.Buckets;
 * };
 * `,
 *     },
 *     description: "List Amazon S3 buckets in us-east-1.",
 *     tracingConfig: {
 *         mode: aws_native.lambda.FunctionTracingConfigMode.Active,
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const _function = new aws_native.lambda.Function("function", {
 *     handler: "index.handler",
 *     role: "arn:aws:iam::123456789012:role/lambda-role",
 *     code: {
 *         s3Bucket: "my-bucket",
 *         s3Key: "function.zip",
 *     },
 *     runtime: "nodejs18.x",
 *     timeout: 5,
 *     tracingConfig: {
 *         mode: aws_native.lambda.FunctionTracingConfigMode.Active,
 *     },
 *     vpcConfig: {
 *         securityGroupIds: ["sg-085912345678492fb"],
 *         subnetIds: [
 *             "subnet-071f712345678e7c8",
 *             "subnet-07fd123456788a036",
 *         ],
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const _function = new aws_native.lambda.Function("function", {
 *     handler: "index.handler",
 *     role: "arn:aws:iam::123456789012:role/lambda-role",
 *     code: {
 *         zipFile: `exports.handler = async (event) => {
 *     console.log(JSON.stringify(event, null, 2));
 *     const response = {
 *         statusCode: 200,
 *         body: JSON.stringify('Hello from Lambda!'),
 *     };
 *     return response;
 * };
 * `,
 *     },
 *     runtime: "nodejs18.x",
 *     tracingConfig: {
 *         mode: aws_native.lambda.FunctionTracingConfigMode.Active,
 *     },
 * });
 * const version = new aws_native.lambda.Version("version", {
 *     functionName: _function.id,
 *     description: "v1",
 *     provisionedConcurrencyConfig: {
 *         provisionedConcurrentExecutions: 20,
 *     },
 * });
 *
 * ```
 */
export declare class Function extends pulumi.CustomResource {
    /**
     * Get an existing Function resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Function;
    /**
     * Returns true if the given object is an instance of Function.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Function;
    /**
     * The instruction set architecture that the function supports. Enter a string array with one of the valid values (arm64 or x86_64). The default value is ``x86_64``.
     */
    readonly architectures: pulumi.Output<enums.lambda.FunctionArchitecturesItem[] | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the function.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The code for the function. You can define your function code in multiple ways:
     *   +  For .zip deployment packages, you can specify the S3 location of the .zip file in the ``S3Bucket``, ``S3Key``, and ``S3ObjectVersion`` properties.
     *   +  For .zip deployment packages, you can alternatively define the function code inline in the ``ZipFile`` property. This method works only for Node.js and Python functions.
     *   +  For container images, specify the URI of your container image in the ECR registry in the ``ImageUri`` property.
     */
    readonly code: pulumi.Output<outputs.lambda.FunctionCode>;
    /**
     * To enable code signing for this function, specify the ARN of a code-signing configuration. A code-signing configuration includes a set of signing profiles, which define the trusted publishers for this function.
     */
    readonly codeSigningConfigArn: pulumi.Output<string | undefined>;
    /**
     * A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see [Dead-letter queues](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-dlq).
     */
    readonly deadLetterConfig: pulumi.Output<outputs.lambda.FunctionDeadLetterConfig | undefined>;
    /**
     * A description of the function.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Environment variables that are accessible from function code during execution.
     */
    readonly environment: pulumi.Output<outputs.lambda.FunctionEnvironment | undefined>;
    /**
     * The size of the function's ``/tmp`` directory in MB. The default value is 512, but it can be any whole number between 512 and 10,240 MB.
     */
    readonly ephemeralStorage: pulumi.Output<outputs.lambda.FunctionEphemeralStorage | undefined>;
    /**
     * Connection settings for an Amazon EFS file system. To connect a function to a file system, a mount target must be available in every Availability Zone that your function connects to. If your template contains an [AWS::EFS::MountTarget](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-mounttarget.html) resource, you must also specify a ``DependsOn`` attribute to ensure that the mount target is created or updated before the function.
     *  For more information about using the ``DependsOn`` attribute, see [DependsOn Attribute](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-dependson.html).
     */
    readonly fileSystemConfigs: pulumi.Output<outputs.lambda.FunctionFileSystemConfig[] | undefined>;
    /**
     * The name of the Lambda function, up to 64 characters in length. If you don't specify a name, CFN generates one.
     *  If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
     */
    readonly functionName: pulumi.Output<string | undefined>;
    /**
     * The name of the method within your code that Lambda calls to run your function. Handler is required if the deployment package is a .zip file archive. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see [Lambda programming model](https://docs.aws.amazon.com/lambda/latest/dg/foundation-progmodel.html).
     */
    readonly handler: pulumi.Output<string | undefined>;
    /**
     * Configuration values that override the container image Dockerfile settings. For more information, see [Container image settings](https://docs.aws.amazon.com/lambda/latest/dg/images-create.html#images-parms).
     */
    readonly imageConfig: pulumi.Output<outputs.lambda.FunctionImageConfig | undefined>;
    /**
     * The ARN of the KMSlong (KMS) customer managed key that's used to encrypt the following resources:
     *   +  The function's [environment variables](https://docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html#configuration-envvars-encryption).
     *   +  The function's [Lambda SnapStart](https://docs.aws.amazon.com/lambda/latest/dg/snapstart-security.html) snapshots.
     *   +  When used with ``SourceKMSKeyArn``, the unzipped version of the .zip deployment package that's used for function invocations. For more information, see [Specifying a customer managed key for Lambda](https://docs.aws.amazon.com/lambda/latest/dg/encrypt-zip-package.html#enable-zip-custom-encryption).
     *   +  The optimized version of the container image that's used for function invocations. Note that this is not the same key that's used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see [Function lifecycle](https://docs.aws.amazon.com/lambda/latest/dg/images-create.html#images-lifecycle).
     *
     *  If you don't provide a customer managed key, Lambda uses an [owned key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk) or an [](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk).
     */
    readonly kmsKeyArn: pulumi.Output<string | undefined>;
    /**
     * A list of [function layers](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html) to add to the function's execution environment. Specify each layer by its ARN, including the version.
     */
    readonly layers: pulumi.Output<string[] | undefined>;
    /**
     * The function's Amazon CloudWatch Logs configuration settings.
     */
    readonly loggingConfig: pulumi.Output<outputs.lambda.FunctionLoggingConfig | undefined>;
    /**
     * The amount of [memory available to the function](https://docs.aws.amazon.com/lambda/latest/dg/configuration-function-common.html#configuration-memory-console) at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB. Note that new AWS accounts have reduced concurrency and memory quotas. AWS raises these quotas automatically based on your usage. You can also request a quota increase.
     */
    readonly memorySize: pulumi.Output<number | undefined>;
    /**
     * The type of deployment package. Set to ``Image`` for container image and set ``Zip`` for .zip file archive.
     */
    readonly packageType: pulumi.Output<enums.lambda.FunctionPackageType | undefined>;
    /**
     * The status of your function's recursive loop detection configuration.
     *  When this value is set to ``Allow``and Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.
     *  When this value is set to ``Terminate`` and Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.
     */
    readonly recursiveLoop: pulumi.Output<enums.lambda.FunctionRecursiveLoop | undefined>;
    /**
     * The number of simultaneous executions to reserve for the function.
     */
    readonly reservedConcurrentExecutions: pulumi.Output<number | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the function's execution role.
     */
    readonly role: pulumi.Output<string>;
    /**
     * The identifier of the function's [runtime](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html). Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you're deploying a function using a container image.
     *  The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see [Runtime use after deprecation](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtime-deprecation-levels).
     *  For a list of all currently supported runtimes, see [Supported runtimes](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtimes-supported).
     */
    readonly runtime: pulumi.Output<string | undefined>;
    /**
     * Sets the runtime management configuration for a function's version. For more information, see [Runtime updates](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-update.html).
     */
    readonly runtimeManagementConfig: pulumi.Output<outputs.lambda.FunctionRuntimeManagementConfig | undefined>;
    /**
     * The function's [SnapStart](https://docs.aws.amazon.com/lambda/latest/dg/snapstart.html) setting.
     */
    readonly snapStart: pulumi.Output<outputs.lambda.FunctionSnapStart | undefined>;
    readonly snapStartResponse: pulumi.Output<outputs.lambda.FunctionSnapStartResponse>;
    /**
     * A list of [tags](https://docs.aws.amazon.com/lambda/latest/dg/tagging.html) to apply to the function.
     *   You must have the ``lambda:TagResource``, ``lambda:UntagResource``, and ``lambda:ListTags`` permissions for your [principal](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html) to manage the CFN stack. If you don't have these permissions, there might be unexpected behavior with stack-level tags propagating to the resource during resource creation and update.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The amount of time (in seconds) that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For more information, see [Lambda execution environment](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-context.html).
     */
    readonly timeout: pulumi.Output<number | undefined>;
    /**
     * Set ``Mode`` to ``Active`` to sample and trace a subset of incoming requests with [X-Ray](https://docs.aws.amazon.com/lambda/latest/dg/services-xray.html).
     */
    readonly tracingConfig: pulumi.Output<outputs.lambda.FunctionTracingConfig | undefined>;
    /**
     * For network connectivity to AWS resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can access resources and the internet only through that VPC. For more information, see [Configuring a Lambda function to access resources in a VPC](https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html).
     */
    readonly vpcConfig: pulumi.Output<outputs.lambda.FunctionVpcConfig | undefined>;
    /**
     * Create a Function resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FunctionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Function resource.
 */
export interface FunctionArgs {
    /**
     * The instruction set architecture that the function supports. Enter a string array with one of the valid values (arm64 or x86_64). The default value is ``x86_64``.
     */
    architectures?: pulumi.Input<pulumi.Input<enums.lambda.FunctionArchitecturesItem>[]>;
    /**
     * The code for the function. You can define your function code in multiple ways:
     *   +  For .zip deployment packages, you can specify the S3 location of the .zip file in the ``S3Bucket``, ``S3Key``, and ``S3ObjectVersion`` properties.
     *   +  For .zip deployment packages, you can alternatively define the function code inline in the ``ZipFile`` property. This method works only for Node.js and Python functions.
     *   +  For container images, specify the URI of your container image in the ECR registry in the ``ImageUri`` property.
     */
    code: pulumi.Input<inputs.lambda.FunctionCodeArgs>;
    /**
     * To enable code signing for this function, specify the ARN of a code-signing configuration. A code-signing configuration includes a set of signing profiles, which define the trusted publishers for this function.
     */
    codeSigningConfigArn?: pulumi.Input<string>;
    /**
     * A dead-letter queue configuration that specifies the queue or topic where Lambda sends asynchronous events when they fail processing. For more information, see [Dead-letter queues](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-dlq).
     */
    deadLetterConfig?: pulumi.Input<inputs.lambda.FunctionDeadLetterConfigArgs>;
    /**
     * A description of the function.
     */
    description?: pulumi.Input<string>;
    /**
     * Environment variables that are accessible from function code during execution.
     */
    environment?: pulumi.Input<inputs.lambda.FunctionEnvironmentArgs>;
    /**
     * The size of the function's ``/tmp`` directory in MB. The default value is 512, but it can be any whole number between 512 and 10,240 MB.
     */
    ephemeralStorage?: pulumi.Input<inputs.lambda.FunctionEphemeralStorageArgs>;
    /**
     * Connection settings for an Amazon EFS file system. To connect a function to a file system, a mount target must be available in every Availability Zone that your function connects to. If your template contains an [AWS::EFS::MountTarget](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-efs-mounttarget.html) resource, you must also specify a ``DependsOn`` attribute to ensure that the mount target is created or updated before the function.
     *  For more information about using the ``DependsOn`` attribute, see [DependsOn Attribute](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-attribute-dependson.html).
     */
    fileSystemConfigs?: pulumi.Input<pulumi.Input<inputs.lambda.FunctionFileSystemConfigArgs>[]>;
    /**
     * The name of the Lambda function, up to 64 characters in length. If you don't specify a name, CFN generates one.
     *  If you specify a name, you cannot perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
     */
    functionName?: pulumi.Input<string>;
    /**
     * The name of the method within your code that Lambda calls to run your function. Handler is required if the deployment package is a .zip file archive. The format includes the file name. It can also include namespaces and other qualifiers, depending on the runtime. For more information, see [Lambda programming model](https://docs.aws.amazon.com/lambda/latest/dg/foundation-progmodel.html).
     */
    handler?: pulumi.Input<string>;
    /**
     * Configuration values that override the container image Dockerfile settings. For more information, see [Container image settings](https://docs.aws.amazon.com/lambda/latest/dg/images-create.html#images-parms).
     */
    imageConfig?: pulumi.Input<inputs.lambda.FunctionImageConfigArgs>;
    /**
     * The ARN of the KMSlong (KMS) customer managed key that's used to encrypt the following resources:
     *   +  The function's [environment variables](https://docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html#configuration-envvars-encryption).
     *   +  The function's [Lambda SnapStart](https://docs.aws.amazon.com/lambda/latest/dg/snapstart-security.html) snapshots.
     *   +  When used with ``SourceKMSKeyArn``, the unzipped version of the .zip deployment package that's used for function invocations. For more information, see [Specifying a customer managed key for Lambda](https://docs.aws.amazon.com/lambda/latest/dg/encrypt-zip-package.html#enable-zip-custom-encryption).
     *   +  The optimized version of the container image that's used for function invocations. Note that this is not the same key that's used to protect your container image in the Amazon Elastic Container Registry (Amazon ECR). For more information, see [Function lifecycle](https://docs.aws.amazon.com/lambda/latest/dg/images-create.html#images-lifecycle).
     *
     *  If you don't provide a customer managed key, Lambda uses an [owned key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk) or an [](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk).
     */
    kmsKeyArn?: pulumi.Input<string>;
    /**
     * A list of [function layers](https://docs.aws.amazon.com/lambda/latest/dg/configuration-layers.html) to add to the function's execution environment. Specify each layer by its ARN, including the version.
     */
    layers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The function's Amazon CloudWatch Logs configuration settings.
     */
    loggingConfig?: pulumi.Input<inputs.lambda.FunctionLoggingConfigArgs>;
    /**
     * The amount of [memory available to the function](https://docs.aws.amazon.com/lambda/latest/dg/configuration-function-common.html#configuration-memory-console) at runtime. Increasing the function memory also increases its CPU allocation. The default value is 128 MB. The value can be any multiple of 1 MB. Note that new AWS accounts have reduced concurrency and memory quotas. AWS raises these quotas automatically based on your usage. You can also request a quota increase.
     */
    memorySize?: pulumi.Input<number>;
    /**
     * The type of deployment package. Set to ``Image`` for container image and set ``Zip`` for .zip file archive.
     */
    packageType?: pulumi.Input<enums.lambda.FunctionPackageType>;
    /**
     * The status of your function's recursive loop detection configuration.
     *  When this value is set to ``Allow``and Lambda detects your function being invoked as part of a recursive loop, it doesn't take any action.
     *  When this value is set to ``Terminate`` and Lambda detects your function being invoked as part of a recursive loop, it stops your function being invoked and notifies you.
     */
    recursiveLoop?: pulumi.Input<enums.lambda.FunctionRecursiveLoop>;
    /**
     * The number of simultaneous executions to reserve for the function.
     */
    reservedConcurrentExecutions?: pulumi.Input<number>;
    /**
     * The Amazon Resource Name (ARN) of the function's execution role.
     */
    role: pulumi.Input<string>;
    /**
     * The identifier of the function's [runtime](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html). Runtime is required if the deployment package is a .zip file archive. Specifying a runtime results in an error if you're deploying a function using a container image.
     *  The following list includes deprecated runtimes. Lambda blocks creating new functions and updating existing functions shortly after each runtime is deprecated. For more information, see [Runtime use after deprecation](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtime-deprecation-levels).
     *  For a list of all currently supported runtimes, see [Supported runtimes](https://docs.aws.amazon.com/lambda/latest/dg/lambda-runtimes.html#runtimes-supported).
     */
    runtime?: pulumi.Input<string>;
    /**
     * Sets the runtime management configuration for a function's version. For more information, see [Runtime updates](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-update.html).
     */
    runtimeManagementConfig?: pulumi.Input<inputs.lambda.FunctionRuntimeManagementConfigArgs>;
    /**
     * The function's [SnapStart](https://docs.aws.amazon.com/lambda/latest/dg/snapstart.html) setting.
     */
    snapStart?: pulumi.Input<inputs.lambda.FunctionSnapStartArgs>;
    /**
     * A list of [tags](https://docs.aws.amazon.com/lambda/latest/dg/tagging.html) to apply to the function.
     *   You must have the ``lambda:TagResource``, ``lambda:UntagResource``, and ``lambda:ListTags`` permissions for your [principal](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html) to manage the CFN stack. If you don't have these permissions, there might be unexpected behavior with stack-level tags propagating to the resource during resource creation and update.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The amount of time (in seconds) that Lambda allows a function to run before stopping it. The default is 3 seconds. The maximum allowed value is 900 seconds. For more information, see [Lambda execution environment](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-context.html).
     */
    timeout?: pulumi.Input<number>;
    /**
     * Set ``Mode`` to ``Active`` to sample and trace a subset of incoming requests with [X-Ray](https://docs.aws.amazon.com/lambda/latest/dg/services-xray.html).
     */
    tracingConfig?: pulumi.Input<inputs.lambda.FunctionTracingConfigArgs>;
    /**
     * For network connectivity to AWS resources in a VPC, specify a list of security groups and subnets in the VPC. When you connect a function to a VPC, it can access resources and the internet only through that VPC. For more information, see [Configuring a Lambda function to access resources in a VPC](https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html).
     */
    vpcConfig?: pulumi.Input<inputs.lambda.FunctionVpcConfigArgs>;
}
